package Mira::View;
$Mira::View::VERSION = '00.07.55';

use strict;
use warnings;
use 5.012;


use Mira::View::Main;
use Mira::View::Floor;
use Mira::View::Feed;
use Mira::View::Archive;
use Mira::View::Post;

1;
__END__

=head1 NAME
Mira Static site generator
