package Mira::CLI;
$Mira::CLI::VERSION = '00.07.55';

use strict;
use warnings;
use App::Cmd::Setup -app;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Mira::CLI - Mira application

=head1 VERSION

version 0.07.51

=head1 AUTHOR

Kiavash Mazi

=head1 COPYRIGHT AND LICENSE

mira is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see L<http://www.gnu.org/licenses/>.

=cut
